|PyPI| |Docs| |License|

.. |PyPI| image:: https://img.shields.io/pypi/v/nabo.svg
        :target: https://pypi.org/project/nabo
.. |Docs| image:: https://readthedocs.org/projects/nabo/badge/?version=latest
        :target: https://nabo.readthedocs.io
.. |License| image:: https://img.shields.io/pypi/l/nabo.svg

====
Nabo
====

|Pic1| 

Nabo is a flexible Python package that allows projections of cells from one
population to another using single-cell RNA-Seq data. Nabo works by setting one
of the populations as a *reference* and then maps cells from other populations
(*target*\s) onto it. Nabo provides data implicit methods of verifying mapping
quality, this allows users to clearly infer similarities between
sub-populations across samples.


.. |Pic1| image:: https://raw.githubusercontent.com/karlssonlab/nabo/master/docs/_static/me_map.png
    :width: 40%

Please refer to the `documentation <https://nabo.readthedocs.io>`__ to know more.
